@@ -1,4 +1,9 @@
 
+package Chart;
+our $VERSION = 2.400.5;
+
+
+$VERSION = Chart;
 =pod
 
 =head1 NAME
